<?php
/**
 * Theme Functions.
 */

/* Theme Setup */
if ( ! function_exists( 'advance_marketing_agency_setup' ) ) :

function advance_marketing_agency_setup() {

	$GLOBALS['content_width'] = apply_filters( 'advance_marketing_agency_content_width', 640 );

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	add_theme_support('responsive-embeds');
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', multi_advance_font_url() ) );
}
endif;
add_action( 'after_setup_theme', 'advance_marketing_agency_setup' );

/* Theme Widgets Setup */
function advance_marketing_agency_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'advance-marketing-agency' ),
		'description'   => __( 'Appears on blog page sidebar', 'advance-marketing-agency' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'advance-marketing-agency' ),
		'description'   => __( 'Appears on page sidebar', 'advance-marketing-agency' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'advance-marketing-agency' ),
		'description'   => __( 'Appears on page sidebar', 'advance-marketing-agency' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$bb_mobile_application_widget_areas = get_theme_mod('bb_mobile_application_footer_widget_areas', '4');
	for ($i=1; $i<=$bb_mobile_application_widget_areas; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Nav ', 'advance-marketing-agency' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s py-3">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title pb-2 mb-3">',
			'after_title'   => '</h3>',
		) );
	}

	register_sidebar( array(
		'name'          => __( 'Shop Page Sidebar', 'advance-marketing-agency' ),
		'description'   => __( 'Appears on shop page', 'advance-marketing-agency' ),
		'id'            => 'woocommerce_sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Single Product Page Sidebar', 'advance-marketing-agency' ),
		'description'   => __( 'Appears on shop page', 'advance-marketing-agency' ),
		'id'            => 'woocommerce-single-sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'advance_marketing_agency_widgets_init' );

add_action( 'wp_enqueue_scripts', 'advance_marketing_agency_enqueue_styles' );
function advance_marketing_agency_enqueue_styles() {
	wp_enqueue_style('bootstrap-style', esc_url(get_template_directory_uri()).'/css/bootstrap.css');
	$parent_style = 'multi-advance-basic-style'; // Style handle of parent theme.
	wp_enqueue_style( $parent_style, esc_url(get_template_directory_uri()) . '/style.css' );
	wp_enqueue_style( 'advance-marketing-agency-style', get_stylesheet_uri(), array( $parent_style ) );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

if ( ! defined( 'MULTI_ADVANCE_PRO_THEME_LINK' ) ) {
	define( 'MULTI_ADVANCE_PRO_THEME_LINK',__('https://www.themeshopy.com/themes/marketing-agent-wordpress-theme/','advance-marketing-agency') );
}

if ( ! defined( 'MULTI_ADVANCE_PRO_THEME_TEXT' ) ) {
	define( 'MULTI_ADVANCE_PRO_THEME_TEXT', __('Advance Marketing Pro','advance-marketing-agency') );
}